function [] = SBT_figs(CPT_num)

% This function may be used for quickly viewing the primary data (qt, fs,
% u2) and soil behavior type index (SBTn) in any of the CSV data files.
% This file should be saved in the same directory as the data files. It
% can be executed by typing 'SBT_figs(nnn)' at the MATLAB command line,
% where nnn = the cone sounding number [201,222].
%
% Note that this function does no error checking, so it is the user's
% responsibility to ensure that the inputs (sounding number and data) are
% reasonable.
%
% T. Matthew Evans
% Oregon State University
% School of Civil and Construction Engineering
% rev0: 04/28/2025

% Read data file
fname = ['SBT_' num2str(CPT_num) '.txt'];
M = readmatrix(fname);

% Create four plots
tiledlayout(1,4);
nexttile
plot(M(:,2),M(:,1));
axis ij
xlabel({'Tip Resistance';'q_t [MPa]'});
ylabel('Distance Below Sea Level, z [m]');
set(gca,'XAxisLocation','top')

nexttile
plot(M(:,3),M(:,1),'r');
axis ij
xlabel({'Sleeve Friction';'f_s [kPa]'});
set(gca,'XAxisLocation','top')

nexttile
plot(M(:,4),M(:,1),'g');
axis ij
xlabel({'Pore Water Pressure';'u_2 [MPa]'});
set(gca,'XAxisLocation','top')

nexttile
plot(M(:,5),M(:,1),'b');
axis ij
xlabel({'Soil Behavior';'Type Index, SBT_n'});
set(gca,'XAxisLocation','top')

sgtitle(['PacWave CPT-' num2str(CPT_num)])